@@ -34,12 +34,13 @@ from ctypes import c_int, c_void_p, c_char_p
 from ctypes.util import find_library
 
 
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 
 _LIB_BASE_NAME = "discid"
 _LIB_MAJOR_VERSION = 0
 
 
+
 def _find_library(name, version=0):
     """Find a library by base-name and major version
     """
@@ -97,7 +98,14 @@ def _find_library(name, version=0):
 def _open_library(lib_name):
     """Open a library by name or location
     """
-    return ctypes.cdll.LoadLibrary(lib_name)
+    try:
+        return ctypes.cdll.LoadLibrary(lib_name)
+    except OSError as exc:
+        if lib_name not in str(exc):
+            # replace uninformative Error on Windows
+            raise OSError("could not find libdiscid: %s" % lib_name)
+        else:
+            raise
 
 _LIB_NAME = _find_library(_LIB_BASE_NAME, _LIB_MAJOR_VERSION)
 _LIB = _open_library(_LIB_NAME)
@@ -173,12 +181,17 @@ given as a :obj:`unicode` or :obj:`str <python:str>` object.
 """
 
 FEATURES = _get_features()
-"""The supported features for the platform as a list of strings.
-The full set currently is ``['read', 'MCN', 'ISRC']``.
+"""The features libdiscid supports for the platform as a list of strings.
 Some Functions can raise :exc:`NotImplementedError` when a feature
 is not available.
+Some features might not be implemented in this python module,
+see :data:`FEATURES_IMPLEMENTED`.
 """
 
+FEATURES_IMPLEMENTED = ["read"]
+"""The features implemented in this python module as a list of strings.
+Some might not be available for your platform, see :data:`FEATURES`.
+"""
 
 class DiscError(IOError):
     """:func:`DiscId.read` will raise this exception when an error occured.
@@ -224,6 +237,7 @@ class DiscId(object):
         That string can be either of:
         :obj:`str <python:str>`, :obj:`unicode` or :obj:`bytes`.
         However, it should in no case contain non-ASCII characters.
+        If no device is given, the :data:`DEFAULT_DEVICE` is used.
 
         A :exc:`DiscError` exception is raised when the reading fails,
         and :exc:`NotImplementedError` when libdiscid doesn't support
@@ -271,6 +285,17 @@ class DiscId(object):
         else:
             return None
 
+    _LIB.discid_get_freedb_id.argtypes = (c_void_p, )
+    _LIB.discid_get_freedb_id.restype = c_char_p
+    def _get_freedb_id(self):
+        """Gets the current FreeDB DiscId
+        """
+        if self._success:
+            result = _LIB.discid_get_freedb_id(self._handle)
+            return _decode(result)
+        else:
+            return None
+
     _LIB.discid_get_submission_url.argtypes = (c_void_p, )
     _LIB.discid_get_submission_url.restype = c_char_p
     def _get_submission_url(self):
@@ -283,6 +308,17 @@ class DiscId(object):
         else:
             return None
 
+    _LIB.discid_get_webservice_url.argtypes = (c_void_p, )
+    _LIB.discid_get_webservice_url.restype = c_char_p
+    def _get_webservice_url(self):
+        """Give an URL to retrieve information about the CD from MusicBrainz.
+        """
+        if self._success:
+            result = _LIB.discid_get_webservice_url(self._handle)
+            return _decode(result)
+        else:
+            return None
+
     _LIB.discid_get_first_track_num.argtypes = (c_void_p, )
     _LIB.discid_get_first_track_num.restype = c_int
     def _get_first_track_num(self):
@@ -323,6 +359,25 @@ class DiscId(object):
             offsets.append(offset)
         return offsets
 
+    _LIB.discid_get_track_length.argtypes = (c_void_p, c_int)
+    _LIB.discid_get_track_length.restype = c_int
+    def _get_track_length(self, track_number):
+        """Gets the length for a specific track
+        """
+        return _LIB.discid_get_track_length(self._handle, track_number)
+
+    def _get_track_lengths(self):
+        """Generates the list of lengths,
+        starting with the lengths of the first pregap
+        """
+        lengths = []
+        lengths.append(self.track_offsets[1])
+        for track_number in range(self.first_track_num,
+                                  self.last_track_num + 1):
+            length = self._get_track_length(track_number)
+            lengths.append(length)
+        return lengths
+
 
     id = property(_get_id, None, None, "MusicBrainz DiscId")
     """This is the MusicBrainz :musicbrainz:`Disc ID`.
@@ -331,6 +386,13 @@ class DiscId(object):
     If set, this is a :obj:`unicode` or :obj:`str <python:str>` object.
     """
 
+    freedb_id = property(_get_freedb_id, None, None, "FreeDB DiscId")
+    """This is the :musicbrainz:`FreeDB` Disc ID (without category).
+
+    It is set after a the TOC was populated or :obj:`None`.
+    If set, this is a :obj:`unicode` or :obj:`str <python:str>` object.
+    """
+
     submission_url = property(_get_submission_url, None, None,
                               "Disc ID / TOC Submission URL for MusicBrainz")
     """With this url you can submit the current TOC
@@ -340,8 +402,16 @@ class DiscId(object):
     Otherwise this is a :obj:`unicode` or :obj:`str <python:str>` object.
     """
 
+    webservice_url = property(_get_webservice_url, None, None,
+                              "web service URL for info about the CD")
+    """With this url you can retrive information about the CD in XML
+    from the MusicBrainz web service.
+
+    If there is no populated TOC the url is :obj:`None`.
+    Otherwise this is a :obj:`unicode` or :obj:`str <python:str>` object.
+    """
     last_track_num = property(_get_last_track_num, None, None,
-                              "Number of the last track")
+                              "Number of the last **audio** track")
 
     first_track_num = property(_get_first_track_num, None, None,
                               "Number of the first track")
@@ -359,6 +429,16 @@ class DiscId(object):
     ``track_offsets[i]`` is the offset for the i-th track (as :obj:`int`).
     """
 
+    track_lengths = property(_get_track_lengths, None, None,
+                              "List of lengths, track_lengths[0] == 1st pregap")
+    """A list of all track lengths.
+
+    The first element is the length of the pregap of the first track.
+    The following elements are the lengths for all **audio** tracks.
+    ``track_length[i]`` is the length for the i-th track (as :obj:`int`).
+    """
+
+
     _LIB.discid_free.argtypes = (c_void_p, )
     _LIB.discid_free.restype = None
     def free(self):
